From d31e6fe45b213eb5033cac5abdece4c2db59d284 Mon Sep 17 00:00:00 2001
From: Christian Heller <c.heller@plomlompom.de>
Date: Sat, 25 Jan 2014 20:30:40 +0100
Subject: [PATCH] Also make the client map window focus on the player when the
 world is re-seeded.

---
 src/client/io.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/client/io.c b/src/client/io.c
index 4623b3d..c2a3b4b 100644
--- a/src/client/io.c
+++ b/src/client/io.c
@@ -67,8 +67,8 @@ static FILE * changed_server_out_file(char * path);
  * a hard-coded serialization format. Returns 1 on success and 0 if the out file
  * wasn't read for supposedly not having changed since a last read_world() call.
  *
  * Note that the first successful read_world() triggers map_center(), so that on
  * start the client focuses the map window on the player.
  */
 static uint8_t read_world();
 
@@ -201,7 +201,7 @@ static uint8_t read_world()
     read_inventory(read_buf, linemax, file);
     world.player_pos.y = read_value_from_line(read_buf, linemax, file);
     world.player_pos.x = read_value_from_line(read_buf, linemax, file);
-    if (first_read)
+    if (1 == world.turn || first_read)
     {
         map_center();
         first_read = 0;
@@ -67,8 +67,8 @@ static FILE * changed_server_out_file(char * path);
  * wasn't read for supposedly not having changed since a last read_world() call.
  *
- * Note that the first successful read_world() triggers map_center(), so that on
- * start the client focuses the map window on the player.
+ * map_center() is triggered by the first successful read_world() or on turn 1,
+ * so the client focuses the map window on the player on client and world start.
  */
 static uint8_t read_world();
-- 
2.30.2